@@ -1,4 +1,9 @@
 package CPANPLUS::Internals::Source::CPANIDX::Tie;
+BEGIN {
+  $CPANPLUS::Internals::Source::CPANIDX::Tie::VERSION = '0.04';
+}
+
+#ABSTRACT: A tie for the CPANIDX source engine
 
 use strict;
 use warnings;
@@ -18,11 +23,9 @@ use CPANPLUS::Internals::Source::CPANIDX::HTTP;
 use Parse::CPAN::Meta;
 
 require Tie::Hash;
-use vars qw[@ISA $VERSION];
+use vars qw[@ISA];
 push @ISA, 'Tie::StdHash';
 
-$VERSION = '0.02';
-
 sub TIEHASH {
     my $class = shift;
     my %hash  = @_;
@@ -169,36 +172,42 @@ sub EXISTS   { !!$_[0]->FETCH( $_[1] ) }
 sub DELETE   {  }
 sub CLEAR    {  }
 
-qq[Tie your mother down]
+qq[Tie your mother down];
+
 
 __END__
+=pod
 
 =head1 NAME
 
 CPANPLUS::Internals::Source::CPANIDX::Tie - A tie for the CPANIDX source engine
 
+=head1 VERSION
+
+version 0.04
+
 =head1 DESCRIPTION
 
 CPANPLUS::Internals::Source::CPANIDX::Tie is a tie for L<CPANPLUS::Internals::Source::CPANIDX>.
 
 It has no user serviceable parts.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-Jos Boumans <kane@cpan.org>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and Jos Boumans
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<CPANPLUS>
 
 L<CPANPLUS::Internals::Source>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Chris Williams and Jos Boumans.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
